@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2021, NVIDIA CORPORATION.  All rights reserved.
+// Copyright (c) 2021 - 2023, NVIDIA CORPORATION.  All rights reserved.
 //
 // NVIDIA CORPORATION and its licensors retain all intellectual property
 // and proprietary rights in and to this software, related documentation
@@ -26,7 +26,9 @@ struct nvswitch_nvlink_vc : public cqi {
     using cqi::cqi;
     [[nodiscard]] virtual auto get_id() const -> id_t = 0;
 
-    struct vc_latency_field : public field<nvswitch_nvlink_vc, readable<nscq_vc_latency_t>> {};
+    struct vc_latency_field : public session_field<nvswitch_nvlink_vc, readable<nscq_vc_latency_t>> {
+        vc_latency_field(std::shared_ptr<nscq::cqi_session> &cqi_session) : session_field<nvswitch_nvlink_vc, readable<nscq_vc_latency_t>>(cqi_session) {}
+    };
     virtual auto get(vc_latency_field) -> nscq_vc_latency_t = 0;
 
 };
